@@ -18,22 +18,22 @@ class ResourceManager(object):
         url = urljoin(self.endpoint, path)
         return url
 
-    def _get(self, path: str, headers: dict = None):
+    def _get(self, path: str, headers: dict = None, query_params: dict = None):
         if headers is None:
             headers = {}
 
         url = urljoin(self.endpoint, path)
 
-        result = self.client.request(url, "GET", headers)
+        result = self.client.request(url, "GET", headers, query_params=query_params)
         return result.json()
 
-    def _delete(self, path: str):
+    def _delete(self, path: str, query_params: dict = None):
         url = urljoin(self.endpoint, path)
 
-        result = self.client.request(url, "DELETE")
+        result = self.client.request(url, "DELETE", query_params=query_params)
         return result
 
-    def _list(self, path: str, filter_params: dict = None):
+    def _list(self, path: str, filter_params: dict = None, query_params: dict = None):
         url = urljoin(self.endpoint, path)
 
         # TODO(ddovbii): add filter handling
@@ -44,7 +44,7 @@ class ResourceManager(object):
 
         return result.json()
 
-    def _post(self, path: str, params: dict = None, headers: dict = None):
+    def _post(self, path: str, params: dict = None, headers: dict = None, query_params: dict = None):
         if headers is None:
             headers = {}
 
