@@ -13,7 +13,7 @@ class BlueprintsCommand(BaseCommand):
     usage:
         torque (bp | blueprint) list [--output=json | --output=json --detail]
         torque (bp | blueprint) validate <file> [--output=json | --output=json --detail]
-        torque (bp | blueprint) get <name> [--source=<source_type>] [--output=json | --output=json --detail]
+        torque (bp | blueprint) get <name> [--repo=<repo_name>] [--output=json | --output=json --detail]
         torque (bp | blueprint) [--help]
 
     options:
@@ -53,13 +53,13 @@ class BlueprintsCommand(BaseCommand):
     def do_get(self) -> (bool, Any):
         detail = self.input_parser.blueprint_get.detail
         blueprint_name = self.input_parser.blueprint_get.blueprint_name
-        source = self.input_parser.blueprint_get.source
+        repo = self.input_parser.blueprint_get.repo
 
         try:
             if detail:
-                bp = self.manager.get_detailed(blueprint_name, source)
+                bp = self.manager.get_detailed(blueprint_name, repo_name=repo)
             else:
-                bp = self.manager.get(blueprint_name, source)
+                bp = self.manager.get(blueprint_name, repo)
         except Exception as e:
             logger.exception(e, exc_info=False)
             return self.die(f"Unable to get details of blueprint '{blueprint_name}'")
