@@ -80,9 +80,8 @@ class BlueprintGetInputParser(BlueprintListInputParser):
         return self._args.get("<name>")
 
     @property
-    def source(self) -> str:
-        source = self._args.get("--source")
-        BlueprintInputValidator.validate_source(source)
+    def repo(self) -> str:
+        source = self._args.get("--repo")
         return source
 
 
@@ -140,6 +139,10 @@ class EnvironmentStartInputParser(InputParserBase):
     def blueprint_name(self) -> str:
         return self._args["<blueprint_name>"]
 
+    @property
+    def repo_name(self) -> str:
+        return self._args["--repo"]
+
     @property
     def branch(self) -> str:
         return self._args.get("--branch")
@@ -171,8 +174,3 @@ class EnvironmentStartInputParser(InputParserBase):
     @property
     def inputs(self) -> dict:
         return parse_comma_separated_string(self._args["--inputs"])
-
-    @property
-    def source(self) -> dict:
-        EnvironmentStartInputValidator.validate_source(self._args)
-        return self._args["--source"]
