@@ -2,8 +2,6 @@ import os.path
 
 from docopt import DocoptExit
 
-from torque.constants import BLUEPRINT_SOURCE_TYPE_API_MAP
-
 
 # generic/shared validations
 class CommandInputValidator:
@@ -14,12 +12,6 @@ class CommandInputValidator:
 
 
 class BlueprintInputValidator:
-    @staticmethod
-    def validate_source(value: str):
-        types = list(BLUEPRINT_SOURCE_TYPE_API_MAP.keys())
-        if value not in types:
-            raise DocoptExit(f"--source value must be in {types}")
-
     @staticmethod
     def validate_blueprint_file_exists(path: str):
         if not os.path.isfile(path):
@@ -54,16 +46,3 @@ class EnvironmentStartInputValidator:
                     raise DocoptExit("Duration must be positive")
             except ValueError:
                 raise DocoptExit("Duration must be a number")
-
-    @staticmethod
-    def validate_source(args: dict):
-        types = list(BLUEPRINT_SOURCE_TYPE_API_MAP.keys())
-        value = args.get("--source", None)
-        if not value:
-            return
-
-        if value not in types:
-            raise DocoptExit(f"--source value must be in {types}")
-
-        if value == "torque" and any([args["--branch"], args["--commit"]]):
-            raise DocoptExit("If blueprint source is 'torque', neither --branch nor --commit must be specified")
