@@ -1,7 +1,7 @@
 import datetime
 
 
-def generate_sandbox_name(blueprint_name: str, temp_working_branch: str, working_branch: str) -> str:
+def generate_environment_name(blueprint_name: str, temp_working_branch: str, working_branch: str) -> str:
     suffix = datetime.datetime.now().strftime("%b%d-%H:%M:%S")
     branch_name_or_type = ""
     if working_branch:
