@@ -12,8 +12,7 @@ Options:
   --token=<token>           Use a specific token for authentication, this will override any default set in the
                             config file
 
-  --account=<account>       [Optional] Your Torque account name. The account name is equal to your subdomain in
-                            the Torque URL. e.g. https://YOURACCOUNT.qtorque.io/
+  --account=<account>       [Optional] Your Torque account name.
 
   --profile=<profile>       Use a specific Profile section in the config file
                             You still can override config with --token/--space options.
@@ -22,7 +21,7 @@ Options:
 
 Commands:
     bp, blueprint       validate torque blueprints
-    sb, sandbox         start sandbox, end sandbox and get its status
+    env, environment    start environment, end environment and get its status
     configure           set, list and remove connection profiles to torque
 """
 import logging
@@ -32,7 +31,7 @@ import pkg_resources
 from colorama import init
 from docopt import DocoptExit, docopt
 
-from torque.commands import bp, configure, sb
+from torque.commands import bp, configure, env
 from torque.models.connection import TorqueConnection
 from torque.parsers.global_input_parser import GlobalInputParser
 from torque.services.connection import TorqueConnectionProvider
@@ -43,8 +42,8 @@ logger = logging.getLogger(__name__)
 commands_table = {
     "bp": bp.BlueprintsCommand,
     "blueprint": bp.BlueprintsCommand,
-    "sb": sb.SandboxesCommand,
-    "sandbox": sb.SandboxesCommand,
+    "env": env.EnvironmentsCommand,
+    "environment": env.EnvironmentsCommand,
     "configure": configure.ConfigureCommand,
 }
 
